==> opigno_lms-8.x-1.4-core.tar.gz: opigno_lms-8.x-1.4/profiles/opigno_lms/modules/opigno/opigno_module/js/opigno_module_activity.js <==
(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.opignoModuleActivity = {
    attach: function (context, settings) {
      var that = this;

      $('.fullscreen-link a', context).click(function(e) {
        e.preventDefault();

        if ($('body').hasClass('fullscreen')) {
          $('body', context).removeClass('fullscreen');
          that.goOutFullscreen();
        }
        else {
          $('body', context).addClass('fullscreen');
          that.goInFullscreen(document.querySelector('html'));
        }
      });

      var activityDeleteForm = $('form.opigno-activity-with-answers');
      if (activityDeleteForm.length) {
        activityDeleteForm.submit();
      }
    },

    goInFullscreen: function (element) {
      if (element.requestFullscreen) {
        element.requestFullscreen();
      }
      else if (element.mozRequestFullScreen) {
        element.mozRequestFullScreen();
      }
      else if (element.webkitRequestFullscreen) {
        element.webkitRequestFullscreen();
      }
      else if (element.msRequestFullscreen) {
        element.msRequestFullscreen();
      }
    },

    goOutFullscreen: function () {
      if (document.exitFullscreen) {
        document.exitFullscreen();
      }
      else if (document.mozCancelFullScreen) {
        document.mozCancelFullScreen();
      }
      else if (document.webkitExitFullscreen) {
        document.webkitExitFullscreen();
      }
      else if (document.msExitFullscreen) {
        document.msExitFullscreen();
      }
    },
  };
}(jQuery, Drupal, drupalSettings));

==> opigno_lms-8.x-2.19-core.tar.gz: opigno_lms-8.x-2.19/profiles/opigno_lms/modules/opigno/opigno_module/js/opigno_module_activity.js <==
(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.opignoModuleActivity = {
    attach: function (context, settings) {
      var that = this;
      var fullScreen = {
        show: function () {
          $('body').addClass('fullscreen');
          that.goInFullscreen(document.querySelector('html'));
        },
        hide: function () {
          $('body').removeClass('fullscreen');
          that.goOutFullscreen();
        }
      };

      $(document).once('opignoModuleActivity').on('fullscreenchange', function (e) {
        if (!this.fullscreen) {
          fullScreen.hide();
        }
      });

      $('.fullscreen-link a', context).once('opignoModuleActivity').on('click', function(e) {
        e.preventDefault();

        if ($('body').hasClass('fullscreen')) {
          fullScreen.hide();
        }
        else {
         fullScreen.show();
        }
      });

      var activityDeleteForm = $('form.opigno-activity-with-answers');
      if (activityDeleteForm.length) {
        activityDeleteForm.submit();
      }
    },

    goInFullscreen: function (element) {
      if (element.requestFullscreen) {
        element.requestFullscreen();
      }
      else if (element.mozRequestFullScreen) {
        element.mozRequestFullScreen();
      }
      else if (element.webkitRequestFullscreen) {
        element.webkitRequestFullscreen();
      }
      else if (element.msRequestFullscreen) {
        element.msRequestFullscreen();
      }
    },

    goOutFullscreen: function () {
      if (document.exitFullscreen) {
        document.exitFullscreen();
      }
      else if (document.mozCancelFullScreen) {
        document.mozCancelFullScreen();
      }
      else if (document.webkitExitFullscreen) {
        document.webkitExitFullscreen();
      }
      else if (document.msExitFullscreen) {
        document.msExitFullscreen();
      }
    },
  };
}(jQuery, Drupal, drupalSettings));
